Home
last modified time | relevance | path

Searched refs:__offset (Results 1 – 17 of 17) sorted by relevance

/freebsd-11-stable/contrib/llvm-project/clang/lib/Headers/
HD__clang_cuda_intrinsics.h25 inline __device__ int __FnName(int __val, __Type __offset, \
27 return __IntIntrinsic(__val, __offset, \
30 inline __device__ float __FnName(float __val, __Type __offset, \
32 return __FloatIntrinsic(__val, __offset, \
35 inline __device__ unsigned int __FnName(unsigned int __val, __Type __offset, \
38 ::__FnName(static_cast<int>(__val), __offset, __width)); \
40 inline __device__ long long __FnName(long long __val, __Type __offset, \
49 __tmp.__a = ::__FnName(__tmp.__a, __offset, __width); \
50 __tmp.__b = ::__FnName(__tmp.__b, __offset, __width); \
55 inline __device__ long __FnName(long __val, __Type __offset, \
[all …]
HDvecintrin.h831 vec_gather_element(vector signed int __vec, vector unsigned int __offset, in vec_gather_element() argument
835 (__INTPTR_TYPE__)__ptr + (__INTPTR_TYPE__)__offset[__index]); in vec_gather_element()
840 vec_gather_element(vector bool int __vec, vector unsigned int __offset, in vec_gather_element() argument
844 (__INTPTR_TYPE__)__ptr + (__INTPTR_TYPE__)__offset[__index]); in vec_gather_element()
849 vec_gather_element(vector unsigned int __vec, vector unsigned int __offset, in vec_gather_element() argument
853 (__INTPTR_TYPE__)__ptr + (__INTPTR_TYPE__)__offset[__index]); in vec_gather_element()
859 vector unsigned long long __offset, in vec_gather_element() argument
863 (__INTPTR_TYPE__)__ptr + (__INTPTR_TYPE__)__offset[__index]); in vec_gather_element()
869 vector unsigned long long __offset, in vec_gather_element() argument
873 (__INTPTR_TYPE__)__ptr + (__INTPTR_TYPE__)__offset[__index]); in vec_gather_element()
[all …]
HDaltivec.h16355 static inline __ATTRS_o_ai vector signed char vec_xl(signed long long __offset, in vec_xl() argument
16357 return *(unaligned_vec_schar *)(__ptr + __offset); in vec_xl()
16361 vec_xl(signed long long __offset, unsigned char *__ptr) { in vec_xl() argument
16362 return *(unaligned_vec_uchar*)(__ptr + __offset); in vec_xl()
16365 static inline __ATTRS_o_ai vector signed short vec_xl(signed long long __offset, in vec_xl() argument
16367 signed char *__addr = (signed char *)__ptr + __offset; in vec_xl()
16372 vec_xl(signed long long __offset, unsigned short *__ptr) { in vec_xl() argument
16373 signed char *__addr = (signed char *)__ptr + __offset; in vec_xl()
16377 static inline __ATTRS_o_ai vector signed int vec_xl(signed long long __offset, in vec_xl() argument
16379 signed char *__addr = (signed char *)__ptr + __offset; in vec_xl()
[all …]
/freebsd-11-stable/contrib/llvm-project/compiler-rt/lib/asan/
HDasan_interceptors_memintrinsics.h53 uptr __offset = (uptr)(offset); \ in DECLARE_REAL()
56 if (__offset > __offset + __size) { \ in DECLARE_REAL()
58 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL()
60 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL()
61 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
/freebsd-11-stable/contrib/libstdc++/include/debug/
Dvector268 difference_type __offset = __position - begin();
273 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
283 difference_type __offset = __position - begin();
288 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
303 difference_type __offset = __position - begin();
309 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
317 difference_type __offset = __position - begin();
319 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
330 difference_type __offset = __first - begin();
333 this->_M_invalidate_if(_After_nth(__offset, _M_base().begin()));
/freebsd-11-stable/contrib/libstdc++/include/std/
Dstd_bitset.h222 const size_t __offset = __shift % _GLIBCXX_BITSET_BITS_PER_WORD; in _M_do_left_shift() local
224 if (__offset == 0) in _M_do_left_shift()
230 - __offset); in _M_do_left_shift()
232 _M_w[__n] = ((_M_w[__n - __wshift] << __offset) in _M_do_left_shift()
234 _M_w[__wshift] = _M_w[0] << __offset; in _M_do_left_shift()
248 const size_t __offset = __shift % _GLIBCXX_BITSET_BITS_PER_WORD; in _M_do_right_shift() local
251 if (__offset == 0) in _M_do_right_shift()
257 - __offset); in _M_do_right_shift()
259 _M_w[__n] = ((_M_w[__n + __wshift] >> __offset) in _M_do_right_shift()
261 _M_w[__limit] = _M_w[_Nw-1] >> __offset; in _M_do_right_shift()
/freebsd-11-stable/contrib/llvm-project/libcxx/include/
HDspan288 subspan(size_type __offset, size_type __count = dynamic_extent) const noexcept
290 _LIBCPP_ASSERT(__offset <= size(), "Offset out of range in span::subspan(offset, count)");
293 return {data() + __offset, size() - __offset};
294 …_LIBCPP_ASSERT(__offset <= size() - __count, "count + offset out of range in span::subspan(offset,…
295 return {data() + __offset, __count};
457 subspan(size_type __offset, size_type __count = dynamic_extent) const noexcept
459 _LIBCPP_ASSERT(__offset <= size(), "Offset out of range in span::subspan(offset, count)");
462 return {data() + __offset, size() - __offset};
463 …_LIBCPP_ASSERT(__offset <= size() - __count, "Offset + count out of range in span::subspan(offset,…
464 return {data() + __offset, __count};
HDregex5961 int __offset = (__flags & regex_constants::match_prev_avail) ? 1 : 0;
5962 basic_string<_CharT> __s(_VSTD::prev(__first, __offset), __last);
5964 bool __r = __e.__search(__s.data() + __offset, __s.data() + __s.size(), __mc, __flags);
/freebsd-11-stable/contrib/libstdc++/include/bits/
Dstl_deque.h185 const difference_type __offset = __n + (_M_cur - _M_first); member
186 if (__offset >= 0 && __offset < difference_type(_S_buffer_size()))
191 __offset > 0 ? __offset / difference_type(_S_buffer_size())
192 : -difference_type((-__offset - 1)
195 _M_cur = _M_first + (__offset - __node_offset
/freebsd-11-stable/include/
HDnl_types.h73 int32_t __offset; member
/freebsd-11-stable/contrib/libstdc++/libsupc++/
Dtinfo.cc322 ptrdiff_t offset = __base_info[i].__offset (); in __do_find_public_src()
448 ptrdiff_t offset = __base_info[i].__offset (); in __do_dyncast()
643 ptrdiff_t offset = __base_info[i].__offset (); in __do_upcast()
Dcxxabi.h327 __offset() const in __offset() function
/freebsd-11-stable/contrib/llvm-project/compiler-rt/lib/msan/
HDmsan_interceptors.cpp103 sptr __offset = __msan_test_shadow(x, n); \
105 if (__offset >= 0 && __msan::flags()->report_umrs) { \
108 ReportUMRInsideAddressRange(__func__, x, n, __offset); \
110 pc, bp, __msan_get_origin((const char *)x + __offset)); \
/freebsd-11-stable/lib/libc/nls/
HDmsgcat.c310 msg_hdr[i].__offset)); in catgets()
/freebsd-11-stable/usr.bin/gencat/
HDgencat.c560 msg_hdr->__offset = htonl(msg_offset);
/freebsd-11-stable/contrib/gcc/cp/
HDChangeLog-20004038 (__base_class_info::__offset): Use a static_cast.
4397 (__base_class_info::__offset): Comment shift.
/freebsd-11-stable/contrib/gcc/
HDFSFChangeLog.105423 * va-alpha.h (__gnuc_va_list): Make __offset an int.
5425 of __offset both both OSF and WINNT.